@@ -1054,23 +1054,21 @@ mate_panel_applet_get_preferred_width (GtkWidget *widget,
 				       int       *minimum_width,
 				       int       *natural_width)
 {
+	MatePanelApplet *applet = MATE_PANEL_APPLET (widget);
+	gint scale;
+
 	GTK_WIDGET_CLASS (mate_panel_applet_parent_class)->get_preferred_width (widget,
 										minimum_width,
 										natural_width);
 
-#if !GTK_CHECK_VERSION (3, 23, 0)
-	MatePanelApplet *applet = MATE_PANEL_APPLET (widget);
 	if (applet->priv->out_of_process) {
-		/* Out-of-process applets end up scaled up doubly with GTK 3.22.
-		 * For these builds divide by the scale factor to ensure
+		/* Out-of-process applets end up scaled up doubly. We divide by the scale factor to ensure
 		 * they are back at their own intended size.
 		 */
-		gint scale;
 		scale = gtk_widget_get_scale_factor (widget);
 		*minimum_width /= scale;
 		*natural_width /= scale;
 	}
-#endif
 }
 
 static void
@@ -1078,23 +1076,21 @@ mate_panel_applet_get_preferred_height (GtkWidget *widget,
 					int       *minimum_height,
 					int       *natural_height)
 {
+	MatePanelApplet *applet = MATE_PANEL_APPLET (widget);
+	gint scale;
+
 	GTK_WIDGET_CLASS (mate_panel_applet_parent_class)->get_preferred_height (widget,
 										minimum_height,
 										natural_height);
 
-#if !GTK_CHECK_VERSION (3, 23, 0)
-	MatePanelApplet *applet = MATE_PANEL_APPLET (widget);
 	if (applet->priv->out_of_process) {
-		gint scale;
-		/* Out-of-process applets end up scaled up doubly with GTK 3.22.
-		 * For these builds divide by the scale factor to ensure
+		/* Out-of-process applets end up scaled up doubly. We divide by the scale factor to ensure
 		 * they are back at their own intended size.
 		 */
 		scale = gtk_widget_get_scale_factor (widget);
 		*minimum_height /= scale;
 		*natural_height /= scale;
 	}
-#endif
 }
 
 static GtkSizeRequestMode
@@ -2300,12 +2296,10 @@ _mate_panel_applet_factory_main_internal (const gchar               *factory_id,
 	g_return_val_if_fail(callback != NULL, 1);
 	g_assert(g_type_is_a(applet_type, PANEL_TYPE_APPLET));
 
-	/*Use this both in and out of process as the tray applet always uses GtkSocket
-	 *to handle GtkStatusIcons whether the tray itself is built in or out of process
-     */
-
-	_mate_panel_applet_setup_x_error_handler();
-
+	if (out_process)
+	{
+		_mate_panel_applet_setup_x_error_handler();
+	}
 
 	closure = g_cclosure_new(G_CALLBACK(callback), user_data, NULL);
 	factory = mate_panel_applet_factory_new(factory_id, out_process,  applet_type, closure);
