@@ -26,12 +26,9 @@
 
 #include "panel-menu-button.h"
 
-#include <X11/Xlib.h>
-
 #include <string.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
-#include <gdk/gdkx.h>
 
 #include <matemenu-tree.h>
 
@@ -95,8 +92,6 @@ struct _PanelMenuButtonPrivate {
 	char                  *custom_icon;
 	char                  *tooltip;
 
-	Window                 interrupted_window;
-
 	MenuPathRoot           path_root;
 	guint                  use_menu_path : 1;
 	guint                  use_custom_icon : 1;
@@ -133,20 +128,33 @@ panel_menu_filename_to_scheme (const char *filename)
 {
 	const char *retval;
 	int         i;
+	gchar *basename;
 
 	retval = NULL;
 
 	if (!filename)
 		return retval;
 
+	/* Note:
+	 * filename in root_items dose not have the parent directory,
+	 * if filename passed is absolute path, this function will return NULL.
+	 * so here use the basename for compare.
+	 */
+	if (g_path_is_absolute (filename)) {
+		basename = g_path_get_basename (filename);
+	} else {
+		basename = g_strdup(filename);
+	}
+
 	for (i = 0; i < G_N_ELEMENTS (root_items); i++) {
 		if (root_items [i].filename &&
-		    !strncmp (filename, root_items [i].filename,
+		    !strncmp (basename, root_items [i].filename,
 			      strlen (root_items [i].filename))) {
 			retval = root_items [i].scheme;
 			break;
 		}
 	}
+	g_free(basename);
 
 	return retval;
 }
@@ -429,23 +437,12 @@ panel_menu_button_recreate_menu (PanelMenuButton *button)
 	button->priv->menu = NULL;
 }
 
-static gboolean panel_menu_button_menu_deactivate (GtkWidget* widget, PanelMenuButton* button)
-{
-	GtkWidget *toplevel = gtk_widget_get_toplevel(widget);
-	panel_util_set_current_active_window(toplevel, button->priv->interrupted_window);
-	button->priv->interrupted_window = None;
-
-	return FALSE;
-}
-
 void
 panel_menu_button_popup_menu (PanelMenuButton *button,
 			      guint            n_button,
 			      guint32          activate_time)
 {
 	GdkScreen *screen;
-	GtkWidget *toplevel;
-	GdkWindow *window;
 
 	g_return_if_fail (PANEL_IS_MENU_BUTTON (button));
 
@@ -465,12 +462,6 @@ panel_menu_button_popup_menu (PanelMenuButton *button,
 			GTK_WIDGET (button),
 			n_button,
 			activate_time);
-
-	g_signal_connect(GTK_MENU_SHELL (button->priv->menu), "deactivate", G_CALLBACK (panel_menu_button_menu_deactivate), button);
-	toplevel = gtk_widget_get_toplevel(GTK_WIDGET(button->priv->toplevel));
-	button->priv->interrupted_window = panel_util_get_current_active_window (toplevel);
-	window = gtk_widget_get_window (toplevel);
-	panel_util_set_current_active_window (toplevel, GDK_WINDOW_XID(window));
 }
 
 static void
@@ -738,8 +729,12 @@ panel_menu_button_get_icon (PanelMenuButton *button)
 			}
 		}
 
-		if (directory)
-			retval = g_strdup (matemenu_tree_directory_get_icon (directory));
+		if (directory) {
+			GIcon  *gicon;
+			gicon = matemenu_tree_directory_get_icon (directory);
+			if (gicon != NULL)
+				retval = g_icon_to_string(gicon);
+		}
 	}
 
 	if (!retval)
