@@ -22,6 +22,7 @@
 #include <gtk/gtkx.h> /* for GTK_IS_SOCKET */
 
 #include <libpanel-util/panel-glib.h>
+#include <libpanel-util/panel-gtk.h>
 
 #include "panel.h"
 
@@ -683,7 +684,7 @@ drop_urilist (PanelWidget *panel,
 				success = FALSE;
 		}
 
-		g_clear_object (&info);
+		g_object_unref (info);
 		g_object_unref (file);
 	}
 
@@ -1342,10 +1343,14 @@ panel_deletion_dialog (PanelToplevel *toplevel)
 	
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 	                                          "%s", text2);	
-	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-				"gtk-cancel", GTK_RESPONSE_CANCEL,
-				"gtk-delete", GTK_RESPONSE_OK,
-				NULL);
+
+	panel_dialog_add_button (GTK_DIALOG (dialog),
+				 _("_Cancel"), "process-stop",
+				 GTK_RESPONSE_CANCEL);
+
+	panel_dialog_add_button (GTK_DIALOG (dialog),
+				 _("_Delete"), "edit-delete",
+				 GTK_RESPONSE_OK);
 
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
 
